@@ -2,11 +2,9 @@ import audearch.analyzer as aa
 import statistics
 
 
-def search(path: str, size: int, imongodb):
+def search_music(list_landamrk, imongodb):
     ids = []
 
-    list_landamrk = aa.analyzer(path, size)
-
     for i, landmark in enumerate(list_landamrk):
         id1, id2, id3 = [], [], []
 
@@ -29,3 +27,21 @@ def search(path: str, size: int, imongodb):
     ans = statistics.mode(ids)
 
     return ans
+
+
+def search(path: str, size: int, imongodb):
+
+    list_landamrk = aa.analyzer(path, size)
+
+    ans = search_music(list_landamrk, imongodb)
+
+    return ans
+
+
+def librosa_search(path: str, size: int, imongodb):
+
+    list_landamrk = aa.librosa_analyzer(path, size)
+
+    ans = search_music(list_landamrk, imongodb)
+
+    return ans
